@@ -40,7 +40,7 @@ help_text = {
     'experiment_parameters': 'Specify the values that the model parameters will be set to before the simulation. Every '
                              'line should contain a single parameter with its value. This value can be defined by '
                              'giving a lower and upper bound where the experiment values will be sampled between in '
-                             '(with brackets). If you want a parameter to have the same value for all experiments, '
+                             '(with brackets).\nIf you want a parameter to have the same value for all experiments, '
                              'simply input the name and the value behind it (without brackets). Model specific values '
                              'need to be in double quotes as shown below, NetLogo primitives like numbers and boolean '
                              'values do not need quotes.\n\n'
@@ -53,7 +53,7 @@ help_text = {
     'experiment_sampling': 'Specify the sampling method that will be used to generate parameter configurations. The '
                            'default is Latin hypercube sampling.\n\n'
                            'Monte Carlo: The parameter values are sampled completely random and independently within '
-                           'the parameter bounds\n\n'
+                           'the parameter bounds.\n\n'
                            'Latin Hypercube: The parameter values are sampled near-random, but depended on each other '
                            'to obtain a good spread.\n\n'
                            'Full factorial: Every possible configuration between the parameter bounds will be sampled.'
